using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using MySql.Data;
using MySql.Data.MySqlClient;

public partial class _InnerJoin : System.Web.UI.Page 
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // Only execute this code if the page load not is a post back.
        if (!Page.IsPostBack)
        {
            // Get values from session variables and store values in hidden fields.
            HiddenYearID.Value = Convert.ToString(Session["YearID"]);
            HiddenCompanyName.Value = Convert.ToString(Session["CompanyName"]);
        }
    }
    protected void BtnCreateJournal_Click(object sender, EventArgs e)
    {
        // Code to select data from three tables with inner joins to connect tables to each other.
        // The data is presented in an repeater control.

        // Declare variables for a connection string and a SELECT statement with inner joins.
        string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "SELECT T.TransID, T.Date, F.FinOwnID, F.FinName, T.Project, T.ResultUnit, "
        + "I.CashAccount, I.BuyAccount, T.Antal, T.Value FROM FinanceTrans As T INNER JOIN FinanceObject "
        + "As F ON T.FinanceObject = F.FID INNER JOIN FinanceInstrument As I ON F.InstrumentType = I.IID "
        + "WHERE T.YearID = @YearID AND T.Accounted = '0' AND T.TransType = '0' AND T.Date <= @Slutdatum "
        + "GROUP BY T.TransID, T.Date, F.FinOwnID, F.FinName, T.Project, T.ResultUnit, I.CashAccount, "
        + "I.BuyAccount, T.Antal, T.Value ORDER BY T.Date ASC";

        // Create a MySqlConnection. The using block is used to call dispose (close) automatically even if 
        // there are an exception.
        using (MySqlConnection cn = new MySqlConnection(ConnString))
        {
            // Create a MySqlCommand.
            MySqlCommand cmd = new MySqlCommand(sql, cn);

            // Add parameters.
            cmd.Parameters.AddWithValue("@Slutdatum", EndDateJournal.Text);
            cmd.Parameters.AddWithValue("@YearID", HiddenYearID.Value);

            // Create a MySqlDataReader
            MySqlDataReader reader = null;

            try
            {
                // Open the connection.
                cn.Open();

                // Execute the SELECT command.
                reader = cmd.ExecuteReader();

                // Bind the result to a Repeater control.
                JournalRepeater.DataSource = reader;
                JournalRepeater.DataBind();
            }
            catch (Exception ex)
            {
                // Catch a general exception
                Response.Write(ex.Message);
            }
            finally
            {
                // Dispose the MySqlCommand
                cmd.Dispose();

                // Close the MySqlDataReader
                if (reader != null)
                    reader.Close();
            }
        }

            // Declare variables to calculate debetsum och creditsum
            decimal KreditSum = decimal.MinValue;
            decimal DebetSum = decimal.MinValue;

            // Code to select cash account data from tables with inner joins to connect the tables to each other
            // The data is presented in an repeater control.

            string ConnStringTwo = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
            string sqlTwo = "SELECT I.CashAccount, T.Project, T.ResultUnit, SUM(T.Value) As Kredit FROM " 
            + "FinanceTrans As T  INNER JOIN FinanceObject As F ON T.FinanceObject = F.FID INNER JOIN " 
            + "FinanceInstrument As I ON F.InstrumentType = I.IID WHERE T.YearID = @YearID AND T.Accounted " 
            + "= '0' AND T.TransType = '0' AND T.Date <= @Slutdatum GROUP BY I.CashAccount, T.Project, " 
            + "T.ResultUnit ORDER BY I.CashAccount ASC";

            // Create a MySqlConnection. The using block is used to call dispose (close) automatically even 
            // if there are an exception.
            using (MySqlConnection cn = new MySqlConnection(ConnStringTwo))
            {
                // Create a MySqlAdapter.
                MySqlDataAdapter ad = new MySqlDataAdapter();

                // Create a MySqlCommand.
                MySqlCommand cmd = new MySqlCommand(sqlTwo, cn);

                // Create a DataSet.
                DataSet ds = new DataSet();

                // Add parameters for the WHERE clause.
                cmd.Parameters.AddWithValue("@Slutdatum", EndDateJournal.Text);
                cmd.Parameters.AddWithValue("@YearID", HiddenYearID.Value);

                // The Try/Catch/Finally block is used to handle exceptions.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Set the SelectCommand for the MySqlDataAdapter
                    ad.SelectCommand = cmd;

                    // Use the MySqlDataAdapter to fill the dataset.
                    ad.Fill(ds);

                    // Bind data to a repeater control with the dataset as the datasource.
                    AccountCashRepeater.DataSource = ds;
                    AccountCashRepeater.DataBind();

                    // Add a value to the KreditSum variable if the value not is Null.
                    if (!DBNull.Value.Equals(ds.Tables[0].Compute("SUM(Kredit)", string.Empty)))
                    {
                        KreditSum = Convert.ToDecimal(ds.Tables[0].Compute("SUM(Kredit)", string.Empty));
                    }
                }
                catch (Exception ex)
                {
                    // Catch a general exception.
                    Response.Write(ex.Message);
                }
                finally
                {
                    // Call Dispose for Adapter, Command and DataSet to avoid memory leakage.
                    ad.Dispose();
                    cmd.Dispose();
                    ds.Dispose();
                }
            }

            // Code to select purchase account data from tables with inner joins to connect the tables to each other
            // The data is presented in an repeater control.

            // Declare variables for a connection string and a SELECT statement with inner joins.
            string ConnStringThree = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
            string sqlThree = "SELECT I.BuyAccount, T.Project, T.ResultUnit, SUM(T.Value) As Debet FROM "
            + "FinanceTrans As T INNER JOIN FinanceObject As F ON T.FinanceObject = F.FID INNER JOIN "
            + "FinanceInstrument As I ON F.InstrumentType = I.IID WHERE T.YearID = @YearID AND T.Accounted = "
            + "'0' AND T.TransType = '0' AND T.Date <= @Slutdatum GROUP BY I.BuyAccount, T.Project, "
            + "T.ResultUnit ORDER BY I.BuyAccount ASC";

            // Create a MySqlConnection. The using block is used to call dispose (close) automatically even 
            // if there are an exception.
            using (MySqlConnection cn = new MySqlConnection(ConnStringThree))
            {
                // Create a MySqlAdapter.
                MySqlDataAdapter ad = new MySqlDataAdapter();

                // Create a MySqlCommand.
                MySqlCommand cmd = new MySqlCommand(sqlThree, cn);

                // Create a DataSet.
                DataSet ds = new DataSet();

                // Add parameters for the WHERE clause.
                cmd.Parameters.AddWithValue("@Slutdatum", EndDateJournal.Text);
                cmd.Parameters.AddWithValue("@YearID", HiddenYearID.Value);
                // The Try/Catch/Finally block is used to handle exceptions.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Set the SelectCommand for the MySqlDataAdapter.
                    ad.SelectCommand = cmd;

                    // Use the MySqlDataAdapter to fill the dataset.
                    ad.Fill(ds);

                    // Bind data to a Repeater control with the dataset as the datasource.
                    AccountBuyRepeater.DataSource = ds;
                    AccountBuyRepeater.DataBind();
                    
                    // Add a value to DebetSum if it not is null.
                    if (!DBNull.Value.Equals(ds.Tables[0].Compute("SUM(Debet)", string.Empty)))
                    {
                        DebetSum = Convert.ToDecimal(ds.Tables[0].Compute("SUM(Debet)", string.Empty));
                    }
                }
                catch (Exception ex)
                {
                    // Catch a general exception.
                    Response.Write(ex.Message);
                }
                finally
                {
                    // Call Dispose for Adapter, Command and DataSet to avoid memory leakage.
                    ad.Dispose();
                    cmd.Dispose();
                    ds.Dispose();
                }
            }

            // Set debetsum and creditsum
            DebetLabel.Text = string.Format("{0:# ### ### ##0.00}", DebetSum);
            KreditLabel.Text = string.Format("{0:# ### ### ##0.00}", KreditSum);
            Sum.Visible = true;
    }
}
